import { Codec, Decoder, Encoder, Option, OptionOrNullable, ReadonlyUint8Array } from '@solana/web3.js';
import { TCollection, TCollectionArgs, TTokenProgramVersion, TTokenProgramVersionArgs, TTokenStandard, TTokenStandardArgs, TUses, TUsesArgs } from '.';
export type TMetadataArgs = {
    /** The name of the asset */
    name: string;
    /** The symbol for the asset */
    symbol: string;
    /** URI pointing to JSON representing the asset */
    uri: string;
    /** Royalty basis points that goes to creators in secondary sales (0-10000) */
    sellerFeeBasisPoints: number;
    primarySaleHappened: boolean;
    isMutable: boolean;
    /** nonce for easy calculation of editions, if present */
    editionNonce: Option<number>;
    /** Since we cannot easily change Metadata, we add the new DataV2 fields here at the end. */
    tokenStandard: Option<TTokenStandard>;
    /** Collection */
    collection: Option<TCollection>;
    /** Uses */
    uses: Option<TUses>;
    tokenProgramVersion: TTokenProgramVersion;
    creatorShares: ReadonlyUint8Array;
    creatorVerified: Array<boolean>;
};
export type TMetadataArgsArgs = {
    /** The name of the asset */
    name: string;
    /** The symbol for the asset */
    symbol: string;
    /** URI pointing to JSON representing the asset */
    uri: string;
    /** Royalty basis points that goes to creators in secondary sales (0-10000) */
    sellerFeeBasisPoints: number;
    primarySaleHappened: boolean;
    isMutable: boolean;
    /** nonce for easy calculation of editions, if present */
    editionNonce: OptionOrNullable<number>;
    /** Since we cannot easily change Metadata, we add the new DataV2 fields here at the end. */
    tokenStandard: OptionOrNullable<TTokenStandardArgs>;
    /** Collection */
    collection: OptionOrNullable<TCollectionArgs>;
    /** Uses */
    uses: OptionOrNullable<TUsesArgs>;
    tokenProgramVersion: TTokenProgramVersionArgs;
    creatorShares: ReadonlyUint8Array;
    creatorVerified: Array<boolean>;
};
export declare function getTMetadataArgsEncoder(): Encoder<TMetadataArgsArgs>;
export declare function getTMetadataArgsDecoder(): Decoder<TMetadataArgs>;
export declare function getTMetadataArgsCodec(): Codec<TMetadataArgsArgs, TMetadataArgs>;
//# sourceMappingURL=tMetadataArgs.d.ts.map